==> querydsl-sql-5.6.1-sources.jar: com/querydsl/sql/oracle/OracleQuery.java <==
/*
 * Copyright 2015, The Querydsl Team (http://www.querydsl.com/team)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.querydsl.sql.oracle;

import com.querydsl.core.DefaultQueryMetadata;
import com.querydsl.core.QueryMetadata;
import com.querydsl.core.Tuple;
import com.querydsl.core.types.Expression;
import com.querydsl.sql.Configuration;
import com.querydsl.sql.OracleTemplates;
import com.querydsl.sql.SQLTemplates;
import java.sql.Connection;
import java.util.function.Supplier;

/**
 * {@code OracleQuery} provides Oracle specific extensions to the base SQL query type
 *
 * <p>If you need to subtype this, use the base class instead.
 *
 * @author tiwe
 * @param <T> result type
 */
public class OracleQuery<T> extends AbstractOracleQuery<T, OracleQuery<T>> {
  public OracleQuery(Connection conn) {
    this(conn, OracleTemplates.DEFAULT, new DefaultQueryMetadata());
  }

  public OracleQuery(Connection conn, SQLTemplates templates) {
    this(conn, templates, new DefaultQueryMetadata());
  }

  public OracleQuery(Connection conn, Configuration configuration) {
    super(conn, configuration, new DefaultQueryMetadata());
  }

  public OracleQuery(Connection conn, Configuration configuration, QueryMetadata metadata) {
    super(conn, configuration, metadata);
  }

  protected OracleQuery(Connection conn, SQLTemplates templates, QueryMetadata metadata) {
    super(conn, new Configuration(templates), metadata);
  }

  public OracleQuery(
      Supplier<Connection> connProvider, Configuration configuration, QueryMetadata metadata) {
    super(connProvider, configuration, metadata);
  }

  public OracleQuery(Supplier<Connection> connProvider, Configuration configuration) {
    super(connProvider, configuration, new DefaultQueryMetadata());
  }

  @Override
  public OracleQuery<T> clone(Connection conn) {
    OracleQuery<T> q = new OracleQuery<T>(conn, getConfiguration(), getMetadata().clone());
    q.clone(this);
    return q;
  }

  @Override
  public <U> OracleQuery<U> select(Expression<U> expr) {
    queryMixin.setProjection(expr);
    @SuppressWarnings("unchecked") // This is the new type
    OracleQuery<U> newType = (OracleQuery<U>) this;
    return newType;
  }

  @Override
  public OracleQuery<Tuple> select(Expression<?>... exprs) {
    queryMixin.setProjection(exprs);
    @SuppressWarnings("unchecked") // This is the new type
    OracleQuery<Tuple> newType = (OracleQuery<Tuple>) this;
    return newType;
  }
}

==> querydsl-sql-6.9-sources.jar: com/querydsl/sql/oracle/OracleQuery.java <==
/*
 * Copyright 2015, The Querydsl Team (http://www.querydsl.com/team)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 * http://www.apache.org/licenses/LICENSE-2.0
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.querydsl.sql.oracle;

import com.querydsl.core.DefaultQueryMetadata;
import com.querydsl.core.QueryMetadata;
import com.querydsl.core.Tuple;
import com.querydsl.core.types.Expression;
import com.querydsl.sql.Configuration;
import com.querydsl.sql.OracleTemplates;
import com.querydsl.sql.SQLTemplates;
import java.sql.Connection;
import java.util.function.Supplier;

/**
 * {@code OracleQuery} provides Oracle specific extensions to the base SQL query type
 *
 * <p>If you need to subtype this, use the base class instead.
 *
 * @author tiwe
 * @param <T> result type
 */
public class OracleQuery<T> extends AbstractOracleQuery<T, OracleQuery<T>> {
  public OracleQuery(Connection conn) {
    this(conn, OracleTemplates.DEFAULT, new DefaultQueryMetadata());
  }

  public OracleQuery(Connection conn, SQLTemplates templates) {
    this(conn, templates, new DefaultQueryMetadata());
  }

  public OracleQuery(Connection conn, Configuration configuration) {
    super(conn, configuration, new DefaultQueryMetadata());
  }

  public OracleQuery(Connection conn, Configuration configuration, QueryMetadata metadata) {
    super(conn, configuration, metadata);
  }

  protected OracleQuery(Connection conn, SQLTemplates templates, QueryMetadata metadata) {
    super(conn, new Configuration(templates), metadata);
  }

  public OracleQuery(
      Supplier<Connection> connProvider, Configuration configuration, QueryMetadata metadata) {
    super(connProvider, configuration, metadata);
  }

  public OracleQuery(Supplier<Connection> connProvider, Configuration configuration) {
    super(connProvider, configuration, new DefaultQueryMetadata());
  }

  @Override
  public OracleQuery<T> clone(Connection conn) {
    var q = new OracleQuery<T>(conn, getConfiguration(), getMetadata().clone());
    q.clone(this);
    return q;
  }

  @Override
  public <U> OracleQuery<U> select(Expression<U> expr) {
    queryMixin.setProjection(expr);
    @SuppressWarnings("unchecked") // This is the new type
    var newType = (OracleQuery<U>) this;
    return newType;
  }

  @Override
  public OracleQuery<Tuple> select(Expression<?>... exprs) {
    queryMixin.setProjection(exprs);
    @SuppressWarnings("unchecked") // This is the new type
    var newType = (OracleQuery<Tuple>) this;
    return newType;
  }
}
